EXPORTS
	??0CShowInfo@@QAE@PAV0@@Z @ 1 NONAME ; CShowInfo::CShowInfo(class CShowInfo *)
	??1CFeedInfo@@UAE@XZ @ 2 NONAME ; CFeedInfo::~CFeedInfo(void)
	??1CPodcastModel@@UAE@XZ @ 3 NONAME ; CPodcastModel::~CPodcastModel(void)
	??1CShowInfo@@UAE@XZ @ 4 NONAME ; CShowInfo::~CShowInfo(void)
	?ActiveClientUid@CFeedEngine@@QAEIXZ @ 5 NONAME ; unsigned int CFeedEngine::ActiveClientUid(void)
	?ActiveFeedInfo@CPodcastModel@@QAEPAVCFeedInfo@@XZ @ 6 NONAME ; class CFeedInfo * CPodcastModel::ActiveFeedInfo(void)
	?ActiveShowList@CPodcastModel@@QAEAAV?$RPointerArray@VCShowInfo@@@@XZ @ 7 NONAME ; class RPointerArray<class CShowInfo> & CPodcastModel::ActiveShowList(void)
	?AddObserver@CFeedEngine@@QAEXPAVMFeedEngineObserver@@@Z @ 8 NONAME ; void CFeedEngine::AddObserver(class MFeedEngineObserver *)
	?AddObserver@CShowEngine@@QAEXPAVMShowEngineObserver@@@Z @ 9 NONAME ; void CShowEngine::AddObserver(class MShowEngineObserver *)
	?AddObserver@CSoundEngine@@QAEXPAVMSoundEngineObserver@@@Z @ 10 NONAME ; void CSoundEngine::AddObserver(class MSoundEngineObserver *)
	?BaseDir@CSettingsEngine@@QAEAAV?$TBuf@$0BAA@@@XZ @ 11 NONAME ; class TBuf<256> & CSettingsEngine::BaseDir(void)
	?ClientState@CFeedEngine@@QAE?AW4TClientState@@XZ @ 12 NONAME ; enum TClientState CFeedEngine::ClientState(void)
	?DeleteAllShowsByFeedL@CShowEngine@@QAEXIH@Z @ 13 NONAME ; void CShowEngine::DeleteAllShowsByFeedL(unsigned int, int)
	?DeletePlayedShows@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 14 NONAME ; void CShowEngine::DeletePlayedShows(class RPointerArray<class CShowInfo> &)
	?DeleteShowL@CShowEngine@@QAEXIH@Z @ 15 NONAME ; void CShowEngine::DeleteShowL(unsigned int, int)
	?Description@CFeedInfo@@QBEABVTDesC16@@XZ @ 16 NONAME ; class TDesC16 const & CFeedInfo::Description(void) const
	?Description@CShowInfo@@QBEABVTDesC16@@XZ @ 17 NONAME ; class TDesC16 const & CShowInfo::Description(void) const
	?DownloadAutomatically@CSettingsEngine@@QAEHXZ @ 18 NONAME ; int CSettingsEngine::DownloadAutomatically(void)
	?ExportFeedsL@CFeedEngine@@QAEHAAV?$TBuf@$0BAA@@@@Z @ 19 NONAME ; int CFeedEngine::ExportFeedsL(class TBuf<256> &)
	?FeedEngine@CPodcastModel@@QAEAAVCFeedEngine@@XZ @ 20 NONAME ; class CFeedEngine & CPodcastModel::FeedEngine(void)
	?FileName@CShowInfo@@QBEABVTDesC16@@XZ @ 21 NONAME ; class TDesC16 const & CShowInfo::FileName(void) const
	?FixProtocolsL@PodcastUtils@@SAXAAVTDes16@@@Z @ 22 NONAME ; void PodcastUtils::FixProtocolsL(class TDes16 &)
	?GetAllShows@CPodcastModel@@QAEXXZ @ 23 NONAME ; void CPodcastModel::GetAllShows(void)
	?GetDownloadedStats@CFeedEngine@@QAEXAAI0@Z @ 24 NONAME ; void CFeedEngine::GetDownloadedStats(unsigned int &, unsigned int &)
	?GetFeedInfoByUid@CFeedEngine@@QAEPAVCFeedInfo@@I@Z @ 25 NONAME ; class CFeedInfo * CFeedEngine::GetFeedInfoByUid(unsigned int)
	?GetMimeType@CShowEngine@@QAEXABVTDesC16@@AAVTDes16@@@Z @ 26 NONAME ; void CShowEngine::GetMimeType(class TDesC16 const &, class TDes16 &)
	?GetNewShows@CPodcastModel@@QAEXXZ @ 27 NONAME ; void CPodcastModel::GetNewShows(void)
	?GetShowByUidL@CShowEngine@@QAEPAVCShowInfo@@I@Z @ 28 NONAME ; class CShowInfo * CShowEngine::GetShowByUidL(unsigned int)
	?GetShowsByFeed@CPodcastModel@@QAEXI@Z @ 29 NONAME ; void CPodcastModel::GetShowsByFeed(unsigned int)
	?GetShowsDownloaded@CPodcastModel@@QAEXXZ @ 30 NONAME ; void CPodcastModel::GetShowsDownloaded(void)
	?GetShowsDownloading@CPodcastModel@@QAEXXZ @ 31 NONAME ; void CPodcastModel::GetShowsDownloading(void)
	?GetSortedFeeds@CFeedEngine@@QAEABV?$RPointerArray@VCFeedInfo@@@@XZ @ 32 NONAME ; class RPointerArray<class CFeedInfo> const & CFeedEngine::GetSortedFeeds(void)
	?IAPIds@CPodcastModel@@QAEAAV?$RArray@VTPodcastIAPItem@@@@XZ @ 33 NONAME ; class RArray<class TPodcastIAPItem> & CPodcastModel::IAPIds(void)
	?IAPNames@CPodcastModel@@QAEPAVCDesC16ArrayFlat@@XZ @ 34 NONAME ; class CDesC16ArrayFlat * CPodcastModel::IAPNames(void)
	?ImageFileName@CFeedInfo@@QBEABVTDesC16@@XZ @ 35 NONAME ; class TDesC16 const & CFeedInfo::ImageFileName(void) const
	?ImageUrl@CFeedInfo@@QBEABVTDesC16@@XZ @ 36 NONAME ; class TDesC16 const & CFeedInfo::ImageUrl(void) const
	?ImportFeedsL@CFeedEngine@@QAEXABVTDesC16@@@Z @ 37 NONAME ; void CFeedEngine::ImportFeedsL(class TDesC16 const &)
	?Link@CFeedInfo@@QBEABVTDesC16@@XZ @ 38 NONAME ; class TDesC16 const & CFeedInfo::Link(void) const
	?MarkSelectionPlayed@CPodcastModel@@QAEXXZ @ 39 NONAME ; void CPodcastModel::MarkSelectionPlayed(void)
	?NewL@CFeedInfo@@SAPAV1@XZ @ 40 NONAME ; class CFeedInfo * CFeedInfo::NewL(void)
	?NewL@CPodcastModel@@SAPAV1@XZ @ 41 NONAME ; class CPodcastModel * CPodcastModel::NewL(void)
	?NewL@CShowInfo@@SAPAV1@I@Z @ 42 NONAME ; class CShowInfo * CShowInfo::NewL(unsigned int)
	?NewLC@CFeedInfo@@SAPAV1@XZ @ 43 NONAME ; class CFeedInfo * CFeedInfo::NewLC(void)
	?Pause@CSoundEngine@@QAEXH@Z @ 44 NONAME ; void CSoundEngine::Pause(int)
	?Play@CSoundEngine@@QAEXXZ @ 45 NONAME ; void CSoundEngine::Play(void)
	?PlayPausePodcastL@CPodcastModel@@QAEXPAVCShowInfo@@H@Z @ 46 NONAME ; void CPodcastModel::PlayPausePodcastL(class CShowInfo *, int)
	?PlayTime@CShowInfo@@QBEIXZ @ 47 NONAME ; unsigned int CShowInfo::PlayTime(void) const
	?PlayingPodcast@CPodcastModel@@QAEPAVCShowInfo@@XZ @ 48 NONAME ; class CShowInfo * CPodcastModel::PlayingPodcast(void)
	?Position@CShowInfo@@QBE?AVTTimeIntervalMicroSeconds@@XZ @ 49 NONAME ; class TTimeIntervalMicroSeconds CShowInfo::Position(void) const
	?Position@CSoundEngine@@QAE?AVTTimeIntervalMicroSeconds@@XZ @ 50 NONAME ; class TTimeIntervalMicroSeconds CSoundEngine::Position(void)
	?PubDate@CShowInfo@@QBE?BVTTime@@XZ @ 51 NONAME ; class TTime const CShowInfo::PubDate(void) const
	?RemoveAllDownloads@CShowEngine@@QAEXXZ @ 52 NONAME ; void CShowEngine::RemoveAllDownloads(void)
	?RemoveDownloadL@CShowEngine@@QAEHI@Z @ 53 NONAME ; int CShowEngine::RemoveDownloadL(unsigned int)
	?RemoveObserver@CFeedEngine@@QAEXPAVMFeedEngineObserver@@@Z @ 54 NONAME ; void CFeedEngine::RemoveObserver(class MFeedEngineObserver *)
	?RemoveObserver@CShowEngine@@QAEXPAVMShowEngineObserver@@@Z @ 55 NONAME ; void CShowEngine::RemoveObserver(class MShowEngineObserver *)
	?ResumeDownloadsL@CShowEngine@@QAEXXZ @ 56 NONAME ; void CShowEngine::ResumeDownloadsL(void)
	?SaveSettingsL@CSettingsEngine@@QAEXXZ @ 57 NONAME ; void CSettingsEngine::SaveSettingsL(void)
	?SetActiveFeedInfo@CPodcastModel@@QAEXPAVCFeedInfo@@@Z @ 58 NONAME ; void CPodcastModel::SetActiveFeedInfo(class CFeedInfo *)
	?SetBaseDir@CSettingsEngine@@QAEXAAV?$TBuf@$0BAA@@@@Z @ 59 NONAME ; void CSettingsEngine::SetBaseDir(class TBuf<256> &)
	?SetBuildDate@CFeedInfo@@QAEXVTTime@@@Z @ 60 NONAME ; void CFeedInfo::SetBuildDate(class TTime)
	?SetCustomTitle@CFeedInfo@@QAEXXZ @ 61 NONAME ; void CFeedInfo::SetCustomTitle(void)
	?SetDescriptionL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 62 NONAME ; void CFeedInfo::SetDescriptionL(class TDesC16 const &)
	?SetDescriptionL@CShowInfo@@QAEXABVTDesC16@@@Z @ 63 NONAME ; void CShowInfo::SetDescriptionL(class TDesC16 const &)
	?SetDownloadAutomatically@CSettingsEngine@@QAEXH@Z @ 64 NONAME ; void CSettingsEngine::SetDownloadAutomatically(int)
	?SetDownloadState@CShowInfo@@QAEXW4TDownloadState@@@Z @ 65 NONAME ; void CShowInfo::SetDownloadState(enum TDownloadState)
	?SetFeedUid@CShowInfo@@QAEXI@Z @ 66 NONAME ; void CShowInfo::SetFeedUid(unsigned int)
	?SetFileNameL@CShowInfo@@QAEXABVTDesC16@@@Z @ 67 NONAME ; void CShowInfo::SetFileNameL(class TDesC16 const &)
	?SetImageFileNameL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 68 NONAME ; void CFeedInfo::SetImageFileNameL(class TDesC16 const &)
	?SetImageUrlL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 69 NONAME ; void CFeedInfo::SetImageUrlL(class TDesC16 const &)
	?SetLastUpdated@CFeedInfo@@QAEXVTTime@@@Z @ 70 NONAME ; void CFeedInfo::SetLastUpdated(class TTime)
	?SetLinkL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 71 NONAME ; void CFeedInfo::SetLinkL(class TDesC16 const &)
	?SetPlayState@CShowInfo@@QAEXW4TPlayState@@@Z @ 72 NONAME ; void CShowInfo::SetPlayState(enum TPlayState)
	?SetPlayTime@CShowInfo@@QAEXI@Z @ 73 NONAME ; void CShowInfo::SetPlayTime(unsigned int)
	?SetPlayingPodcast@CPodcastModel@@QAEXPAVCShowInfo@@@Z @ 74 NONAME ; void CPodcastModel::SetPlayingPodcast(class CShowInfo *)
	?SetPosition@CShowInfo@@QAEXVTTimeIntervalMicroSeconds@@@Z @ 75 NONAME ; void CShowInfo::SetPosition(class TTimeIntervalMicroSeconds)
	?SetPosition@CSoundEngine@@QAEXI@Z @ 76 NONAME ; void CSoundEngine::SetPosition(unsigned int)
	?SetPubDate@CShowInfo@@QAEXVTTime@@@Z @ 77 NONAME ; void CShowInfo::SetPubDate(class TTime)
	?SetShowSize@CShowInfo@@QAEXI@Z @ 78 NONAME ; void CShowInfo::SetShowSize(unsigned int)
	?SetShowType@CShowInfo@@QAEXW4TShowType@@@Z @ 79 NONAME ; void CShowInfo::SetShowType(enum TShowType)
	?SetSpecificIAP@CSettingsEngine@@QAEXH@Z @ 80 NONAME ; void CSettingsEngine::SetSpecificIAP(int)
	?SetTitleL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 81 NONAME ; void CFeedInfo::SetTitleL(class TDesC16 const &)
	?SetTitleL@CShowInfo@@QAEXABVTDesC16@@@Z @ 82 NONAME ; void CShowInfo::SetTitleL(class TDesC16 const &)
	?SetTrackNo@CShowInfo@@QAEXI@Z @ 83 NONAME ; void CShowInfo::SetTrackNo(unsigned int)
	?SetUid@CShowInfo@@QAEXI@Z @ 84 NONAME ; void CShowInfo::SetUid(unsigned int)
	?SetUpdateAutomatically@CSettingsEngine@@QAEXW4TAutoUpdateSetting@@@Z @ 85 NONAME ; void CSettingsEngine::SetUpdateAutomatically(enum TAutoUpdateSetting)
	?SetUpdateFeedInterval@CSettingsEngine@@QAEXH@Z @ 86 NONAME ; void CSettingsEngine::SetUpdateFeedInterval(int)
	?SetUpdateFeedTime@CSettingsEngine@@QAEXVTTime@@@Z @ 87 NONAME ; void CSettingsEngine::SetUpdateFeedTime(class TTime)
	?SetUrlL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 88 NONAME ; void CFeedInfo::SetUrlL(class TDesC16 const &)
	?SetUrlL@CShowInfo@@QAEXABVTDesC16@@@Z @ 89 NONAME ; void CShowInfo::SetUrlL(class TDesC16 const &)
	?SettingsEngine@CPodcastModel@@QAEAAVCSettingsEngine@@XZ @ 90 NONAME ; class CSettingsEngine & CPodcastModel::SettingsEngine(void)
	?ShowDownloading@CShowEngine@@QAEPAVCShowInfo@@XZ @ 91 NONAME ; class CShowInfo * CShowEngine::ShowDownloading(void)
	?ShowEngine@CPodcastModel@@QAEAAVCShowEngine@@XZ @ 92 NONAME ; class CShowEngine & CPodcastModel::ShowEngine(void)
	?SoundEngine@CPodcastModel@@QAEAAVCSoundEngine@@XZ @ 93 NONAME ; class CSoundEngine & CPodcastModel::SoundEngine(void)
	?SpecificIAP@CSettingsEngine@@QAEHXZ @ 94 NONAME ; int CSettingsEngine::SpecificIAP(void)
	?State@CSoundEngine@@QAE?AW4TSoundEngineState@@XZ @ 95 NONAME ; enum TSoundEngineState CSoundEngine::State(void)
	?Stop@CSoundEngine@@QAEXH@Z @ 96 NONAME ; void CSoundEngine::Stop(int)
	?Title@CFeedInfo@@QBEABVTDesC16@@XZ @ 97 NONAME ; class TDesC16 const & CFeedInfo::Title(void) const
	?Title@CShowInfo@@QBEABVTDesC16@@XZ @ 98 NONAME ; class TDesC16 const & CShowInfo::Title(void) const
	?TrackNo@CShowInfo@@QBEIXZ @ 99 NONAME ; unsigned int CShowInfo::TrackNo(void) const
	?Uid@CShowInfo@@QBEIXZ @ 100 NONAME ; unsigned int CShowInfo::Uid(void) const
	?SNAPNames@CPodcastModel@@QAEPAVCDesC16ArrayFlat@@XZ @ 101 NONAME ; class CDesC16ArrayFlat * CPodcastModel::SNAPNames(void)
	?UpdateAutomatically@CSettingsEngine@@QAE?AW4TAutoUpdateSetting@@XZ @ 102 NONAME ; enum TAutoUpdateSetting CSettingsEngine::UpdateAutomatically(void)
	?UpdateFeed@CFeedEngine@@QAEXPAVCFeedInfo@@@Z @ 103 NONAME ; void CFeedEngine::UpdateFeed(class CFeedInfo *)
	?UpdateFeedInterval@CSettingsEngine@@QAEHXZ @ 104 NONAME ; int CSettingsEngine::UpdateFeedInterval(void)
	?UpdateFeedL@CFeedEngine@@QAEHI@Z @ 105 NONAME ; int CFeedEngine::UpdateFeedL(unsigned int)
	?UpdateFeedTime@CSettingsEngine@@QAE?AVTTime@@XZ @ 106 NONAME ; class TTime CSettingsEngine::UpdateFeedTime(void)
	?AddDownloadL@CShowEngine@@QAEXAAVCShowInfo@@@Z @ 107 NONAME ; void CShowEngine::AddDownloadL(class CShowInfo &)
	?Url@CFeedInfo@@QBEABVTDesC16@@XZ @ 108 NONAME ; class TDesC16 const & CFeedInfo::Url(void) const
	?Url@CShowInfo@@QBEABVTDesC16@@XZ @ 109 NONAME ; class TDesC16 const & CShowInfo::Url(void) const
	?RemoveFeedL@CFeedEngine@@QAEXI@Z @ 110 NONAME ; void CFeedEngine::RemoveFeedL(unsigned int)
	??1CShowEngine@@UAE@XZ @ 111 NONAME ; CShowEngine::~CShowEngine(void)
	?DBGetShowByFileNameL@CShowEngine@@QAEPAVCShowInfo@@V?$TBuf@$0BAA@@@@Z @ 112 NONAME ; class CShowInfo * CShowEngine::DBGetShowByFileNameL(class TBuf<256>)
	?DeleteOldShowsByFeed@CShowEngine@@QAEXI@Z @ 113 NONAME ; void CShowEngine::DeleteOldShowsByFeed(unsigned int)
	?GetAllShowsL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 114 NONAME ; void CShowEngine::GetAllShowsL(class RPointerArray<class CShowInfo> &)
	?GetNewShowsL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 115 NONAME ; void CShowEngine::GetNewShowsL(class RPointerArray<class CShowInfo> &)
	?GetNextShowByTrackL@CShowEngine@@QAEPAVCShowInfo@@PAV2@@Z @ 116 NONAME ; class CShowInfo * CShowEngine::GetNextShowByTrackL(class CShowInfo *)
	?GetNumDownloadingShows@CShowEngine@@QAEHXZ @ 117 NONAME ; int CShowEngine::GetNumDownloadingShows(void)
	?GetShowsByFeedL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@I@Z @ 118 NONAME ; void CShowEngine::GetShowsByFeedL(class RPointerArray<class CShowInfo> &, unsigned int)
	?GetShowsDownloadedL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 119 NONAME ; void CShowEngine::GetShowsDownloadedL(class RPointerArray<class CShowInfo> &)
	?GetShowsDownloadingL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 120 NONAME ; void CShowEngine::GetShowsDownloadingL(class RPointerArray<class CShowInfo> &)
	?MetaDataReader@CShowEngine@@QAEAAVCMetaDataReader@@XZ @ 121 NONAME ; class CMetaDataReader & CShowEngine::MetaDataReader(void)
	?NewL@CShowEngine@@SAPAV1@AAVCPodcastModel@@@Z @ 122 NONAME ; class CShowEngine * CShowEngine::NewL(class CPodcastModel &)
	?NewLC@CShowInfo@@SAPAV1@I@Z @ 123 NONAME ; class CShowInfo * CShowInfo::NewLC(unsigned int)
	?NotifyShowListUpdatedL@CShowEngine@@QAEXXZ @ 124 NONAME ; void CShowEngine::NotifyShowListUpdatedL(void)
	?CancelUpdateAllFeeds@CFeedEngine@@QAEXXZ @ 125 NONAME ; void CFeedEngine::CancelUpdateAllFeeds(void)
	?ConnectionEngine@CPodcastModel@@QAEAAVCConnectionEngine@@XZ @ 126 NONAME ; class CConnectionEngine & CPodcastModel::ConnectionEngine(void)
	?SetLastError@CFeedInfo@@QAEXH@Z @ 127 NONAME ; void CFeedInfo::SetLastError(int)
	?SetLastError@CShowInfo@@QAEXH@Z @ 128 NONAME ; void CShowInfo::SetLastError(int)
	?LastError@CFeedInfo@@QBEHXZ @ 129 NONAME ; int CFeedInfo::LastError(void) const
	?LastError@CShowInfo@@QBEHXZ @ 130 NONAME ; int CShowInfo::LastError(void) const
	?AddSearchResultL@CFeedEngine@@QAEXPAVCFeedInfo@@@Z @ 131 NONAME ; void CFeedEngine::AddSearchResultL(class CFeedInfo *)
	?GetSearchResults@CFeedEngine@@QAEABV?$RPointerArray@VCFeedInfo@@@@XZ @ 132 NONAME ; class RPointerArray<class CFeedInfo> const & CFeedEngine::GetSearchResults(void)
	?GetStatsByFeed@CFeedEngine@@QAEXIAAI0@Z @ 133 NONAME ; void CFeedEngine::GetStatsByFeed(unsigned int, unsigned int &, unsigned int &)
	?SearchForFeedL@CFeedEngine@@QAEXAAVTDesC16@@@Z @ 134 NONAME ; void CFeedEngine::SearchForFeedL(class TDesC16 &)
	?AddFeedL@CFeedEngine@@QAEHABVCFeedInfo@@@Z @ 135 NONAME ; int CFeedEngine::AddFeedL(class CFeedInfo const &)
	?BuildDate@CFeedInfo@@QBE?AVTTime@@XZ @ 136 NONAME ; class TTime CFeedInfo::BuildDate(void) const
	?CopyL@CFeedInfo@@QBEPAV1@XZ @ 137 NONAME ; class CFeedInfo * CFeedInfo::CopyL(void) const
	?CustomTitle@CFeedInfo@@QBEHXZ @ 138 NONAME ; int CFeedInfo::CustomTitle(void) const
	?LastUpdated@CFeedInfo@@QBE?AVTTime@@XZ @ 139 NONAME ; class TTime CFeedInfo::LastUpdated(void) const
	?Uid@CFeedInfo@@QBEIXZ @ 140 NONAME ; unsigned int CFeedInfo::Uid(void) const
	?AddShowL@CShowEngine@@QAEHABVCShowInfo@@@Z @ 141 NONAME ; int CShowEngine::AddShowL(class CShowInfo const &)
	?DownloadState@CShowInfo@@QBE?AW4TDownloadState@@XZ @ 142 NONAME ; enum TDownloadState CShowInfo::DownloadState(void) const
	?FeedUid@CShowInfo@@QBEIXZ @ 143 NONAME ; unsigned int CShowInfo::FeedUid(void) const
	?PlayState@CShowInfo@@QBE?AW4TPlayState@@XZ @ 144 NONAME ; enum TPlayState CShowInfo::PlayState(void) const
	?ShowSize@CShowInfo@@QBEIXZ @ 145 NONAME ; unsigned int CShowInfo::ShowSize(void) const
	?ShowType@CShowInfo@@QBE?AW4TShowType@@XZ @ 146 NONAME ; enum TShowType CShowInfo::ShowType(void) const
	?UpdateShow@CShowEngine@@QAEXAAVCShowInfo@@@Z @ 147 NONAME ; void CShowEngine::UpdateShow(class CShowInfo &)
	?UpdateIAPListL@CPodcastModel@@QAEXXZ @ 148 NONAME ; void CPodcastModel::UpdateIAPListL(void)
	?UpdateSNAPListL@CPodcastModel@@QAEXXZ @ 149 NONAME ; void CPodcastModel::UpdateSNAPListL(void)
	?SNAPIds@CPodcastModel@@QAEAAV?$RArray@VTPodcastIAPItem@@@@XZ @ 150 NONAME ; class RArray<class TPodcastIAPItem> & CPodcastModel::SNAPIds(void)
	?UpdateAllFeedsL@CFeedEngine@@QAEXH@Z @ 151 NONAME ; void CFeedEngine::UpdateAllFeedsL(int)
	?CleanHtmlL@PodcastUtils@@SAXAAVTDes16@@@Z @ 152 NONAME ; void PodcastUtils::CleanHtmlL(class TDes16 &)
	?DownloadSuspended@CSettingsEngine@@QAEHXZ @ 153 NONAME ; int CSettingsEngine::DownloadSuspended(void)
	?EnsureProperPathName@PodcastUtils@@SAXAAV?$TBuf@$0BAA@@@@Z @ 154 NONAME ; void PodcastUtils::EnsureProperPathName(class TBuf<256> &)
	?FileNameFromUrl@PodcastUtils@@SAXABVTDesC16@@AAV?$TBuf@$0BAA@@@@Z @ 155 NONAME ; void PodcastUtils::FileNameFromUrl(class TDesC16 const &, class TBuf<256> &)
	?IsFirstStartup@CPodcastModel@@QAEHXZ @ 156 NONAME ; int CPodcastModel::IsFirstStartup(void)
	?OpmlParsingComplete@CFeedEngine@@QAEXI@Z @ 157 NONAME ; void CFeedEngine::OpmlParsingComplete(unsigned int)
	?ReplaceChar@PodcastUtils@@SAXAAVTDes16@@II@Z @ 158 NONAME ; void PodcastUtils::ReplaceChar(class TDes16 &, unsigned int, unsigned int)
	?ReplaceString@PodcastUtils@@SAXAAVTDes16@@ABVTDesC16@@1@Z @ 159 NONAME ; void PodcastUtils::ReplaceString(class TDes16 &, class TDesC16 const &, class TDesC16 const &)
	?SQLEncode@PodcastUtils@@SAXAAVTDes16@@@Z @ 160 NONAME ; void PodcastUtils::SQLEncode(class TDes16 &)
	?SetDownloadSuspended@CSettingsEngine@@QAEXH@Z @ 161 NONAME ; void CSettingsEngine::SetDownloadSuspended(int)
	?SuspendDownloads@CShowEngine@@QAEXXZ @ 162 NONAME ; void CShowEngine::SuspendDownloads(void)
	?XMLEncode@PodcastUtils@@SAXAAVTDes16@@@Z @ 163 NONAME ; void PodcastUtils::XMLEncode(class TDes16 &)
	?FeedIcon@CFeedInfo@@QBEPAVCFbsBitmap@@XZ @ 164 NONAME ; class CFbsBitmap * CFeedInfo::FeedIcon(void) const
	?SetFeedIcon@CFeedInfo@@QAEXPAVCFbsBitmap@@@Z @ 165 NONAME ; void CFeedInfo::SetFeedIcon(class CFbsBitmap *)
	??1CImageHandler@@UAE@XZ @ 166 NONAME ; CImageHandler::~CImageHandler(void)
	?LoadFileAndScaleL@CImageHandler@@QAEXPAVCFbsBitmap@@ABV?$TBuf@$0BAA@@@ABVTSize@@AAVMImageHandlerCallback@@H@Z @ 167 NONAME ; void CImageHandler::LoadFileAndScaleL(class CFbsBitmap *, class TBuf<256> const &, class TSize const &, class MImageHandlerCallback &, int)
	?NewL@CImageHandler@@SAPAV1@AAVRFs@@@Z @ 168 NONAME ; class CImageHandler * CImageHandler::NewL(class RFs &)
	?NewLC@CImageHandler@@SAPAV1@AAVRFs@@@Z @ 169 NONAME ; class CImageHandler * CImageHandler::NewLC(class RFs &)
	?ScaledBitmap@CImageHandler@@QAEPAVCFbsBitmap@@XZ @ 170 NONAME ; class CFbsBitmap * CImageHandler::ScaledBitmap(void)
	?ImageHandler@CPodcastModel@@QAEAAVCImageHandler@@XZ @ 171 NONAME ; class CImageHandler & CPodcastModel::ImageHandler(void)

